@@ -2,15 +2,16 @@
 # -*- coding: utf-8 -*-
 """Provide a device, connected via the PI GCS DLL."""
 
-from logging import debug
 from abc import abstractmethod
+from ...PILogger import PIDebug
 from ..interfaces.gcsdll import GCSDll
+from ..interfaces.piusb import PIUSB
 from .. import gcserror
 from .gcsbasecommands import GCSBaseCommands
 from ..gcsmessages import GCSMessages
 from .. import GCSError
 
-__signature__ = 0xd305a21eea77d22fea1dc73b502b88fc
+__signature__ = 0xa2e1583a480974544ec45412c526c3df
 
 
 # Invalid method name pylint: disable=C0103
@@ -34,6 +35,14 @@ class GCSBaseDevice(GCSBaseCommands):
     def __exit__(self, exc_type, exc_val, exc_tb):
         self.close()
 
+    @property
+    def gcsdevice(self):
+        """
+        returns the gcs device object
+        :return: instance of GCSBaseDevice or GCS2Device or GCS30Device
+        """
+        return self
+
     @property
     def dcid(self):
         """Get ID of current daisy chain connection as integer."""
@@ -59,7 +68,7 @@ class GCSBaseDevice(GCSBaseCommands):
 
     def unload(self):
         """Close connection to device and daisy chain and unload GCS DLL."""
-        debug('GCSBaseDevice.unload()')
+        PIDebug('GCSBaseDevice.unload()')
         del self.funcs
         del self.devname
         del self.axes
@@ -145,12 +154,18 @@ class GCSBaseDevice(GCSBaseCommands):
         """
         self.dll.ConnectTCPIPByDescription(description)
 
-    def ConnectUSB(self, serialnum):
+    def ConnectUSB(self, serialnum, pid=None, vid=0x1a72):
         """Open an USB connection to a device.
         @param serialnum: Serial number of device or one of the
         identification strings listed by EnumerateUSB().
+        @param pid : USB Product ID of the device (only for native usb).
+        @param vid : USB Vendor ID of the device  (only for native usb).
         """
-        self.dll.ConnectUSB(serialnum)
+        if isinstance(self.dll, PIUSB):
+            self.dll.ConnectUSB(serialnum, pid, vid)
+        else:
+            self.dll.ConnectUSB(serialnum)
+
 
     def ConnectNIgpib(self, board, device):
         """Open a connection from a NI IEEE 488 board to the device.
