@@ -3,15 +3,15 @@
 """Wrapper to access a PI GCS DLL."""
 
 import ctypes
-from logging import debug, warning
 import os
 from platform import architecture
 import sys
 
+from ...PILogger import PIDebug, PIWarning
 from .. import GCSError
-from .. interfaces.pigateway import PIGateway
+from .. interfaces.pigateway import PIGateway, PI_CONTROLLER_CODEPAGE
 
-__signature__ = 0x5331a832c47bb4c5e25eb1ef3a1efe13
+__signature__ = 0x5bdbf03cef3f70c56d0d11225b73e72d
 
 DLLDEVICES = {
     'C7XX_GCS_DLL': ['C-702', ],
@@ -33,6 +33,8 @@ UNIXDLL = {
     'PI_GCS2_DLL': 'libpi_pi_gcs2',
 }
 
+PI_DLL_CODEPAGE = PI_CONTROLLER_CODEPAGE
+
 
 def get_dll_name(devname):
     """Get according name of 32 or 64 bit PI GCS DLL for 'devname'.
@@ -117,10 +119,9 @@ def read_registry_gcstranslator(gcsdir):
     @param gcsdir : Default GCSTranslator directory.
     @return : GCSTranslator directory as string from registry or 'gcsdir' if reading registry fails.
     """
-    try:
-        import winreg  # Python 3
-    except ImportError:
-        import _winreg as winreg  # Python 2
+    # Import outside toplevel (winreg) pylint: disable=C0415
+    import winreg  # Python 3
+
     if 'PROGRAMW6432' in os.environ:
         regkey = r'SOFTWARE\Wow6432Node\PI\GCSTranslator'
     else:
@@ -131,9 +132,9 @@ def read_registry_gcstranslator(gcsdir):
         gcsdir = winreg.QueryValueEx(keyhandle, 'Path')[0]
         winreg.CloseKey(keyhandle)
     except WindowsError:
-        warning('no GCSTranslator path in Windows registry (HKLM\\%s)', regkey)
+        PIWarning('no GCSTranslator path in Windows registry (HKLM\\%s)', regkey)
     else:
-        debug('read HKLM\\%s: %r', regkey, gcsdir)
+        PIDebug('read HKLM\\%s: %r', regkey, gcsdir)
     finally:
         winreg.CloseKey(reghandle)
     return gcsdir
@@ -150,7 +151,7 @@ class GCSDll(PIGateway):
         @param devname : Name of device, chooses according DLL which defaults to PI_GCS2_DLL.
         @param dllname : Name or path to GCS DLL to use, overwrites 'devname'.
         """
-        debug('create an instance of GCSDll(devname=%r, dllname=%r)', devname, dllname)
+        PIDebug('create an instance of GCSDll(devname=%r, dllname=%r)', devname, dllname)
         dllname = dllname or get_dll_name(devname)
         self._timeout = 7000  # milliseconds
         self._dllpath = get_dll_path(dllname)
@@ -183,7 +184,7 @@ class GCSDll(PIGateway):
         try:
             getattr(self._handle, self._prefix + 'SetTimeout')(self._id, cvalue)
         except AttributeError:
-            debug('GCSDLL.settimeout: cannot set timeout in GCS DLL')
+            PIDebug('GCSDLL.settimeout: cannot set timeout in GCS DLL')
 
     @property
     def warning(self):
@@ -197,20 +198,20 @@ class GCSDll(PIGateway):
         """Set the current warning to 'msg' as string."""
         self._warnmsg = msg
         if self._warnmsg:
-            debug('GCSDll.warning = %s', self._warnmsg)
+            PIDebug('GCSDll.warning = %s', self._warnmsg)
 
     def send(self, msg):
         """Send a GCS command to the device, do not query error from device.
         @param msg : GCS command as string, with or without trailing line feed character.
         """
-        debug('GCSDll.send(id%d): %r', self._id, msg)
-        msg = ctypes.c_char_p(str(msg).encode('cp1252'))
+        PIDebug('GCSDll.send(id%d): %r', self._id, msg)
+        msg = ctypes.c_char_p(str(msg).encode(PI_DLL_CODEPAGE))
         if not getattr(self._handle, self._prefix + 'GcsCommandset')(self._id, msg):
             raise GCSError(self._error)
 
     def flush(self):
         """Flush input buffer and set DLL timeout value."""
-        debug('GCSDll.flush()')
+        PIDebug('GCSDll.flush()')
         self.settimeout(self._timeout)  # to initially set timeout value of the DLL
         while self._answersize:
             _ = self._getanswer(self._answersize)
@@ -228,7 +229,7 @@ class GCSDll(PIGateway):
         @param bufsize : Size in characters of string buffer to store the answer as integer.
         @return : Answer as string.
         """
-        bufstr = ctypes.create_string_buffer('\000'.encode(), bufsize + 2)
+        bufstr = ctypes.create_string_buffer('\000'.encode(PI_DLL_CODEPAGE), bufsize + 2)
         if not getattr(self._handle, self._prefix + 'GcsGetAnswer')(self._id, bufstr, bufsize + 1):
             raise GCSError(self._error)
         return bufstr.value
@@ -239,13 +240,13 @@ class GCSDll(PIGateway):
         """
         if self._answersize:
             received = self._getanswer(self._answersize)
-            debug('GCSDll.read: %r', received)
-            return received
+            PIDebug('GCSDll.read: %r', received)
+            return received.decode(encoding=PI_DLL_CODEPAGE, errors='ignore')
         return u''
 
     def close(self):
         """Close connection to device and daisy chain."""
-        debug('GCSDll.close(id%d)', self._id)
+        PIDebug('GCSDll.close(id%d)', self._id)
         if self._id >= 0:
             self.CloseConnection()
         if self._dcid >= 0:
@@ -253,9 +254,7 @@ class GCSDll(PIGateway):
 
     def unload(self):
         """Close connection to device and daisy chain and unload GCS DLL."""
-        if self._dllhandle is None:
-            warning('GCSDll.unload: cannot unload %r', self._dllpath)
-        else:
+        if self._dllhandle is not None:
             self.close()
             # Access to a protected member _handle of a client class pylint: disable=W0212
             if sys.platform in ('win32', 'cygwin'):
@@ -263,7 +262,7 @@ class GCSDll(PIGateway):
             else:
                 ctypes.cdll.LoadLibrary(str(self._dllpath)).dlclose(ctypes.c_int(self._dllhandle._handle))
             self._dllhandle = None
-            debug('GCSDll.unload %r', self._dllpath)
+            PIDebug('GCSDll.unload %r', self._dllpath)
 
     @property
     def _error(self):
@@ -276,7 +275,7 @@ class GCSDll(PIGateway):
         if self._dllhandle is None:
             if not os.path.isfile(self._dllpath):
                 raise IOError('%r not found' % self._dllpath)
-            debug('GCSDll.load: %r', self._dllpath)
+            PIDebug('GCSDll.load: %r', self._dllpath)
             if sys.platform in ('win32', 'cygwin'):
                 self._dllhandle = ctypes.windll.LoadLibrary(str(self._dllpath))
             else:
@@ -298,6 +297,8 @@ class GCSDll(PIGateway):
                 self._dllprefix = 'Hydra_'
             elif dllname.find('PI_G_GCS2_DLL') > -1:
                 self._dllprefix = 'PI_G_'
+            elif dllname.find('libpi_pi_gcs2') > -1:
+                self._dllprefix = 'PI_'
             else:
                 self._dllprefix = '%s_' % dllname.split('_')[0]
         return self._dllprefix
@@ -331,8 +332,8 @@ class GCSDll(PIGateway):
         @param numtables : Arrange data into 'numtables' columns, defaults to "1".
         @return: List of data points as float with 'numtables' columns.
         """
-        debug('DEPRECATED -- GcsDll.GetAsyncBuffer(id%d, firstline=%r, lastline=%r, numtables=%r)', self._id,
-              firstline, lastline, numtables)
+        PIDebug('DEPRECATED -- GcsDll.GetAsyncBuffer(id%d, firstline=%r, lastline=%r, numtables=%r)', self._id,
+                firstline, lastline, numtables)
         maxindex = lastline * numtables or self._asyncbufferindex
         if firstline < 1:
             raise SystemError('firstline must be 1 or larger')
@@ -345,7 +346,7 @@ class GCSDll(PIGateway):
         data = [[] for _ in range(numtables)]
         for i in range(minindex, maxindex):
             data[i % numtables].append(float(cvalues[i]))
-        debug('DEPRECATED -- GCSDll.GetAsyncBuffer(id%d): %r', self._id, data)
+        PIDebug('DEPRECATED -- GCSDll.GetAsyncBuffer(id%d): %r', self._id, data)
         return data
 
     def GetAsyncBufferIndex(self):
@@ -354,7 +355,7 @@ class GCSDll(PIGateway):
         @return: Buffer index as integer.
         """
         bufindex = getattr(self._handle, self._prefix + 'GetAsyncBufferIndex')(self._id)
-        debug('DEPRECATED -- GCSDll.GetAsyncBufferIndex(id%d): %r', self._id, bufindex)
+        PIDebug('DEPRECATED -- GCSDll.GetAsyncBufferIndex(id%d): %r', self._id, bufindex)
         self._asyncbufferindex = bufindex
         return bufindex
 
@@ -370,13 +371,14 @@ class GCSDll(PIGateway):
         """Open dialog to select the interface.
         @param key: Optional key name as string to store the settings in the Windows registry.
         """
-        debug('GCSDll.InterfaceSetupDlg(key=%r)', key)
-        key = ctypes.c_char_p(str(key).encode())
+        PIDebug('GCSDll.InterfaceSetupDlg(key=%r)', key)
+        key = ctypes.c_char_p(str(key).encode(PI_DLL_CODEPAGE))
         self._id = getattr(self._handle, self._prefix + 'InterfaceSetupDlg')(key)
         if self._id < 0:
             raise GCSError(self._error)
         self._ifdescription = 'Interface Setup Dialog'
         self.flush()
+        self.call_connection_status_changed_callback(self)
 
     def ConnectRS232(self, comport, baudrate):
         """Open an RS-232 connection to the device.
@@ -387,63 +389,67 @@ class GCSDll(PIGateway):
         try:
             comport = int(comport)
         except ValueError:
-            debug('GCSDll.ConnectRS232ByDevName(devname=%r, baudrate=%s)', comport, baudrate)
-            cdevname = ctypes.c_char_p(str(comport).encode())
+            PIDebug('GCSDll.ConnectRS232ByDevName(devname=%r, baudrate=%s)', comport, baudrate)
+            cdevname = ctypes.c_char_p(str(comport).encode(PI_DLL_CODEPAGE))
             self._id = getattr(self._handle, self._prefix + 'ConnectRS232ByDevName')(cdevname, cbaudrate)
         else:
-            debug('GCSDll.ConnectRS232(comport=%s, baudrate=%s)', comport, baudrate)
+            PIDebug('GCSDll.ConnectRS232(comport=%s, baudrate=%s)', comport, baudrate)
             ccomport = ctypes.c_int(int(comport))
             self._id = getattr(self._handle, self._prefix + 'ConnectRS232')(ccomport, cbaudrate)
         if self._id < 0:
             raise GCSError(self._error)
         self._ifdescription = 'RS-232 port %s, %s Baud' % (comport, baudrate)
         self.flush()
+        self.call_connection_status_changed_callback(self)
 
     def ConnectTCPIP(self, ipaddress, ipport=50000):
         """Open a TCP/IP connection to the device.
         @param ipaddress: IP address to connect to as string.
         @param ipport: Port to use as integer, defaults to 50000.
         """
-        debug('GCSDll.ConnectTCPIP(ipaddress=%s, ipport=%s)', ipaddress, ipport)
-        cipaddress = ctypes.c_char_p(str(ipaddress).encode())
+        PIDebug('GCSDll.ConnectTCPIP(ipaddress=%s, ipport=%s)', ipaddress, ipport)
+        cipaddress = ctypes.c_char_p(str(ipaddress).encode(PI_DLL_CODEPAGE))
         cipport = ctypes.c_int(int(ipport))
         self._id = getattr(self._handle, self._prefix + 'ConnectTCPIP')(cipaddress, cipport)
         if self._id < 0:
             raise GCSError(self._error)
         self._ifdescription = 'TCPIP %s:%s' % (ipaddress, ipport)
         self.flush()
+        self.call_connection_status_changed_callback(self)
 
     def ConnectTCPIPByDescription(self, description):
         """Open a TCP/IP connection to the device using the device 'description'.
         @param description: One of the identification strings listed by EnumerateTCPIPDevices().
         """
-        debug('GCSDll.ConnectTCPIPByDescription(description=%r)', description)
-        cdescription = ctypes.c_char_p(str(description).encode())
+        PIDebug('GCSDll.ConnectTCPIPByDescription(description=%r)', description)
+        cdescription = ctypes.c_char_p(str(description).encode(PI_DLL_CODEPAGE))
         self._id = getattr(self._handle, self._prefix + 'ConnectTCPIPByDescription')(cdescription)
         if self._id < 0:
             raise GCSError(self._error)
         self._ifdescription = 'TCPIP %r' % description
         self.flush()
+        self.call_connection_status_changed_callback(self)
 
     def ConnectUSB(self, serialnum):
         """Open an USB connection to a device.
         @param serialnum: Serial number of device or one of the
         identification strings listed by EnumerateUSB().
         """
-        debug('GCSDll.ConnectUSB(serialnum=%r)', serialnum)
-        cserialnum = ctypes.c_char_p(str(serialnum).encode())
+        PIDebug('GCSDll.ConnectUSB(serialnum=%r)', serialnum)
+        cserialnum = ctypes.c_char_p(str(serialnum).encode(PI_DLL_CODEPAGE))
         self._id = getattr(self._handle, self._prefix + 'ConnectUSB')(cserialnum)
         if self._id < 0:
             raise GCSError(self._error)
         self._ifdescription = 'USB %r' % serialnum
         self.flush()
+        self.call_connection_status_changed_callback(self)
 
     def ConnectNIgpib(self, board, device):
         """Open a connection from a NI IEEE 488 board to the device.
         @param board: GPIB board ID as integer.
         @param device: The GPIB device ID of the device as integer.
         """
-        debug('GCSDll.ConnectNIgpib(board=%s, device=%s)', board, device)
+        PIDebug('GCSDll.ConnectNIgpib(board=%s, device=%s)', board, device)
         cboard = ctypes.c_int(int(board))
         cdevice = ctypes.c_int(int(device))
         self._id = getattr(self._handle, self._prefix + 'ConnectNIgpib')(cboard, cdevice)
@@ -451,12 +457,13 @@ class GCSDll(PIGateway):
             raise GCSError(self._error)
         self._ifdescription = 'GPIB board %s, device %s' % (board, device)
         self.flush()
+        self.call_connection_status_changed_callback(self)
 
     def ConnectPciBoard(self, board):
         """Open a PCI board connection.
         @param board : PCI board number as integer.
         """
-        debug('GCSDll.ConnectPciBoard(board=%s)', board)
+        PIDebug('GCSDll.ConnectPciBoard(board=%s)', board)
         cboard = ctypes.c_int(int(board))
         if self._prefix == 'C843_':
             self._id = getattr(self._handle, self._prefix + 'Connect')(cboard)
@@ -466,21 +473,22 @@ class GCSDll(PIGateway):
             raise GCSError(self._error)
         self._ifdescription = 'PCI board %s' % board
         self.flush()
+        self.call_connection_status_changed_callback(self)
 
     def EnumerateUSB(self, mask=''):
         """Get identification strings of all USB connected devices.
         @param mask: String to filter the results for certain text.
         @return: Found devices as list of strings.
         """
-        debug('GCSDll.EnumerateUSB(mask=%r)', mask)
-        mask = ctypes.c_char_p(str(mask).encode())
+        PIDebug('GCSDll.EnumerateUSB(mask=%r)', mask)
+        mask = ctypes.c_char_p(str(mask).encode(PI_DLL_CODEPAGE))
         bufsize = 100000
-        bufstr = ctypes.create_string_buffer('\000'.encode(), bufsize + 2)
+        bufstr = ctypes.create_string_buffer('\000'.encode(PI_DLL_CODEPAGE), bufsize + 2)
         if getattr(self._handle, self._prefix + 'EnumerateUSB')(bufstr, bufsize, mask) < 0:
             raise GCSError(self._error)
-        devlist = bufstr.value.decode(encoding='cp1252', errors='ignore').split('\n')[:-1]
+        devlist = bufstr.value.decode(encoding=PI_DLL_CODEPAGE, errors='ignore').split('\n')[:-1]
         devlist = [item.strip() for item in devlist]
-        debug('GCSDll.EnumerateUSB: %r', devlist)
+        PIDebug('GCSDll.EnumerateUSB: %r', devlist)
         return devlist
 
     def EnumerateTCPIPDevices(self, mask=''):
@@ -488,15 +496,15 @@ class GCSDll(PIGateway):
         @param mask: String to filter the results for certain text.
         @return: Found devices as list of strings.
         """
-        debug('GCSDll.EnumerateTCPIPDevices(mask=%r)', mask)
-        mask = ctypes.c_char_p(str(mask).encode())
+        PIDebug('GCSDll.EnumerateTCPIPDevices(mask=%r)', mask)
+        mask = ctypes.c_char_p(str(mask).encode(PI_DLL_CODEPAGE))
         bufsize = 100000
-        bufstr = ctypes.create_string_buffer('\000'.encode(), bufsize + 2)
+        bufstr = ctypes.create_string_buffer('\000'.encode(PI_DLL_CODEPAGE), bufsize + 2)
         if getattr(self._handle, self._prefix + 'EnumerateTCPIPDevices')(bufstr, bufsize, mask) < 0:
             raise GCSError(self._error)
-        devlist = bufstr.value.decode(encoding='cp1252', errors='ignore').split('\n')[:-1]
+        devlist = bufstr.value.decode(encoding=PI_DLL_CODEPAGE, errors='ignore').split('\n')[:-1]
         devlist = [item.strip() for item in devlist]
-        debug('GCSDll.EnumerateTCPIPDevices: %r', devlist)
+        PIDebug('GCSDll.EnumerateTCPIPDevices: %r', devlist)
         return devlist
 
     def OpenRS232DaisyChain(self, comport, baudrate):
@@ -506,20 +514,21 @@ class GCSDll(PIGateway):
         @param baudrate: Baudrate to use as integer.
         @return: Found devices as list of strings.
         """
-        debug('GCSDll.OpenRS232DaisyChain(comport=%s, baudrate=%s)', comport, baudrate)
+        PIDebug('GCSDll.OpenRS232DaisyChain(comport=%s, baudrate=%s)', comport, baudrate)
         ccomport = ctypes.c_int(int(comport))
         cbaudrate = ctypes.c_int(int(baudrate))
         numdev = ctypes.byref(ctypes.c_int())
         bufsize = 10000
-        bufstr = ctypes.create_string_buffer('\000'.encode(), bufsize + 2)
+        bufstr = ctypes.create_string_buffer('\000'.encode(PI_DLL_CODEPAGE), bufsize + 2)
         self._dcid = getattr(self._handle, self._prefix + 'OpenRS232DaisyChain')(ccomport, cbaudrate, numdev, bufstr,
                                                                                  bufsize)
         if self._dcid < 0:
             raise GCSError(self._error)
-        devlist = bufstr.value.decode(encoding='cp1252', errors='ignore').split('\n')[:-1]
+        devlist = bufstr.value.decode(encoding=PI_DLL_CODEPAGE, errors='ignore').split('\n')[:-1]
         devlist = [item.strip() for item in devlist]
-        debug('GCSDll.OpenRS232DaisyChain: %r', devlist)
+        PIDebug('GCSDll.OpenRS232DaisyChain: %r', devlist)
         self._ifdescription = 'RS-232 daisy chain at COM%s, %s Baud' % (comport, baudrate)
+        self.call_connection_status_changed_callback(self)
         return devlist
 
     def OpenUSBDaisyChain(self, description):
@@ -528,18 +537,19 @@ class GCSDll(PIGateway):
         @param description: Description of the device returned by EnumerateUSB().
         @return: Found devices as list of strings.
         """
-        debug('GCSDll.OpenUSBDaisyChain(description=%r)', description)
-        cdescription = ctypes.c_char_p(str(description).encode())
+        PIDebug('GCSDll.OpenUSBDaisyChain(description=%r)', description)
+        cdescription = ctypes.c_char_p(str(description).encode(PI_DLL_CODEPAGE))
         numdev = ctypes.byref(ctypes.c_int())
         bufsize = 10000
-        bufstr = ctypes.create_string_buffer('\000'.encode(), bufsize + 2)
+        bufstr = ctypes.create_string_buffer('\000'.encode(PI_DLL_CODEPAGE), bufsize + 2)
         self._dcid = getattr(self._handle, self._prefix + 'OpenUSBDaisyChain')(cdescription, numdev, bufstr, bufsize)
         if self._dcid < 0:
             raise GCSError(self._error)
-        devlist = bufstr.value.decode(encoding='cp1252', errors='ignore').split('\n')[:-1]
+        devlist = bufstr.value.decode(encoding=PI_DLL_CODEPAGE, errors='ignore').split('\n')[:-1]
         devlist = [item.strip() for item in devlist]
-        debug('GCSDll.OpenUSBDaisyChain: %r', devlist)
+        PIDebug('GCSDll.OpenUSBDaisyChain: %r', devlist)
         self._ifdescription = 'USB daisy chain at SN %r' % description
+        self.call_connection_status_changed_callback(self)
         return devlist
 
     def OpenTCPIPDaisyChain(self, ipaddress, ipport=50000):
@@ -549,20 +559,21 @@ class GCSDll(PIGateway):
         @param ipport: Port to use as integer, defaults to 50000.
         @return: Found devices as list of strings.
         """
-        debug('GCSDll.OpenTCPIPDaisyChain(ipaddress=%r, ipport=%s)', ipaddress, ipport)
-        cipaddress = ctypes.c_char_p(str(ipaddress).encode())
+        PIDebug('GCSDll.OpenTCPIPDaisyChain(ipaddress=%r, ipport=%s)', ipaddress, ipport)
+        cipaddress = ctypes.c_char_p(str(ipaddress).encode(PI_DLL_CODEPAGE))
         cipport = ctypes.c_int(int(ipport))
         numdev = ctypes.byref(ctypes.c_int())
         bufsize = 10000
-        bufstr = ctypes.create_string_buffer('\000'.encode(), bufsize + 2)
+        bufstr = ctypes.create_string_buffer('\000'.encode(PI_DLL_CODEPAGE), bufsize + 2)
         self._dcid = getattr(self._handle, self._prefix + 'OpenTCPIPDaisyChain')(cipaddress, cipport, numdev, bufstr,
                                                                                  bufsize)
         if self._dcid < 0:
             raise GCSError(self._error)
-        devlist = bufstr.value.decode(encoding='cp1252', errors='ignore').split('\n')[:-1]
+        devlist = bufstr.value.decode(encoding=PI_DLL_CODEPAGE, errors='ignore').split('\n')[:-1]
         devlist = [item.strip() for item in devlist]
-        debug('GCSDll.OpenTCPIPDaisyChain: %r', devlist)
+        PIDebug('GCSDll.OpenTCPIPDaisyChain: %r', devlist)
         self._ifdescription = 'TCPIP daisy chain at %s:%s' % (ipaddress, ipport)
+        self.call_connection_status_changed_callback(self)
         return devlist
 
     def ConnectDaisyChainDevice(self, deviceid, daisychainid=None):
@@ -571,8 +582,8 @@ class GCSDll(PIGateway):
         @param daisychainid : Daisy chain ID as int from the daisy chain master instance or None.
         @param deviceid : Device ID on the daisy chain as integer.
         """
-        debug('GCSDll.ConnectDaisyChainDevice(deviceid=%s, daisychainid=%s)', deviceid,
-              daisychainid)
+        PIDebug('GCSDll.ConnectDaisyChainDevice(deviceid=%s, daisychainid=%s)', deviceid,
+                daisychainid)
         if daisychainid is None:
             daisychainid = self._dcid
         cdeviceid = ctypes.c_int(int(deviceid))
@@ -583,18 +594,20 @@ class GCSDll(PIGateway):
         if self._ifdescription:
             self._ifdescription += '; '
         self._ifdescription += 'daisy chain %d, device %s' % (daisychainid, deviceid)
+        self.call_connection_status_changed_callback(self)
         self.flush()
 
     def CloseConnection(self):
         """Close connection to the device."""
-        debug('GCSDll.CloseConnection(id=%d)', self._id)
+        PIDebug('GCSDll.CloseConnection(id=%d)', self._id)
         getattr(self._handle, self._prefix + 'CloseConnection')(self._id)
+        self.call_connection_status_changed_callback(self)
         self._ifdescription = self._ifdescription.split(';')[0]
         self._id = -1
 
     def CloseDaisyChain(self):
         """Close all connections on daisy chain and daisy chain connection itself."""
-        debug('GCSDll.CloseDaisyChain(dcid=%d)', self._dcid)
+        PIDebug('GCSDll.CloseDaisyChain(dcid=%d)', self._dcid)
         getattr(self._handle, self._prefix + 'CloseDaisyChain')(self._dcid)
         self._ifdescription = ''
         self._id = -1
@@ -604,8 +617,8 @@ class GCSDll(PIGateway):
         """Add a dataset for a user defined stage to the PI stages database.
         @param axis: Name of axis whose stage parameters should be added as string.
         """
-        debug('GCSDll.AddStage(axis=%r)', axis)
-        axis = ctypes.c_char_p(str(axis).encode())
+        PIDebug('GCSDll.AddStage(axis=%r)', axis)
+        axis = ctypes.c_char_p(str(axis).encode(PI_DLL_CODEPAGE))
         if not getattr(self._handle, self._prefix + 'AddStage')(self._id, axis):
             raise GCSError(self._error)
 
@@ -613,8 +626,8 @@ class GCSDll(PIGateway):
         """Remove a dataset of a user defined stage from the PI stages database.
         @param axis: Name of axis whose stage parameters should be removed as string.
         """
-        debug('GCSDll.RemoveStage(axis=%r)', axis)
-        axis = ctypes.c_char_p(str(axis).encode())
+        PIDebug('GCSDll.RemoveStage(axis=%r)', axis)
+        axis = ctypes.c_char_p(str(axis).encode(PI_DLL_CODEPAGE))
         if not getattr(self._handle, self._prefix + 'RemoveStage')(self._id, axis):
             raise GCSError(self._error)
 
@@ -623,7 +636,7 @@ class GCSDll(PIGateway):
         :param timeout: timeout in ms.
         :type timeout: int
         """
-        debug('GCSDll.SetConnectTimeout(timeout=%s)', timeout)
+        PIDebug('GCSDll.SetConnectTimeout(timeout=%s)', timeout)
         ctimeout = ctypes.c_int(int(timeout))
         getattr(self._handle, self._prefix + 'SetConnectTimeout')(ctimeout)
 
@@ -632,7 +645,7 @@ class GCSDll(PIGateway):
         :param enable_bautrate_scan: if 'True' the baud rate scan is enabled, else it is disabled
         :type enable_bautrate_scan: bool
         """
-        debug('GCSDll.EnableBaudRateScan(timeout=%s)', enable_bautrate_scan)
+        PIDebug('GCSDll.EnableBaudRateScan(timeout=%s)', enable_bautrate_scan)
         cenable_bautrate_scan = ctypes.c_int(int(enable_bautrate_scan))
         getattr(self._handle, self._prefix + 'EnableBaudRateScan')(cenable_bautrate_scan)
 
@@ -643,11 +656,11 @@ class GCSDll(PIGateway):
         @param config: Name of a configuration existing in PIStages database as string.
         @param andsave: saves the configuration to non volatile memory on the controller.
         """
-        debug('GCSDll.applyconfig(items=%r, config=%r)', items, config)
-        items = ctypes.c_char_p(str(items).encode())
-        config = ctypes.c_char_p(str(config).encode())
+        PIDebug('GCSDll.applyconfig(items=%r, config=%r)', items, config)
+        items = ctypes.c_char_p(str(items).encode(PI_DLL_CODEPAGE))
+        config = ctypes.c_char_p(str(config).encode(PI_DLL_CODEPAGE))
         bufsize = 20000
-        warnings = ctypes.create_string_buffer('\000'.encode(), bufsize + 2)
+        warnings = ctypes.create_string_buffer('\000'.encode(PI_DLL_CODEPAGE), bufsize + 2)
 
         if not andsave:
             funcname = self._prefix + 'WriteConfigurationFromDatabaseToController'
@@ -655,7 +668,7 @@ class GCSDll(PIGateway):
             funcname = self._prefix + 'WriteConfigurationFromDatabaseToControllerAndSave'
 
         if not getattr(self._handle, funcname)(self._id, items, config, warnings, bufsize + 1):
-            self.warning = warnings.value.decode(encoding='cp1252', errors='ignore')
+            self.warning = warnings.value.decode(encoding=PI_DLL_CODEPAGE, errors='ignore')
             raise GCSError(self._error)
 
     def saveconfig(self, items, config):
@@ -664,28 +677,28 @@ class GCSDll(PIGateway):
         Consists of the key word (e.g. "axis") and ID  (e.g. "4"), examples: "axis 1", "axis 4".
         @param config: Name of a configuration not yet existing in PIStages database as string.
         """
-        debug('GCSDll.saveconfig(items=%r, config=%r)', items, config)
-        items = ctypes.c_char_p(str(items).encode())
-        config = ctypes.c_char_p(str(config).encode())
+        PIDebug('GCSDll.saveconfig(items=%r, config=%r)', items, config)
+        items = ctypes.c_char_p(str(items).encode(PI_DLL_CODEPAGE))
+        config = ctypes.c_char_p(str(config).encode(PI_DLL_CODEPAGE))
         bufsize = 20000
-        warnings = ctypes.create_string_buffer('\000'.encode(), bufsize + 2)
+        warnings = ctypes.create_string_buffer('\000'.encode(PI_DLL_CODEPAGE), bufsize + 2)
         funcname = self._prefix + 'ReadConfigurationFromControllerToDatabase'
         if not getattr(self._handle, funcname)(self._id, items, config, warnings, bufsize + 1):
-            self.warning = warnings.value.decode(encoding='cp1252', errors='ignore')
+            self.warning = warnings.value.decode(encoding=PI_DLL_CODEPAGE, errors='ignore')
             raise GCSError(self._error)
 
     def getconfigs(self):
         """Get available configurations in PIStages database for the connected controller.
         @return : Answer as string.
         """
-        debug('GCSDll.getconfigs()')
+        PIDebug('GCSDll.getconfigs()')
         bufsize = 20000
-        configs = ctypes.create_string_buffer('\000'.encode(), bufsize + 2)
+        configs = ctypes.create_string_buffer('\000'.encode(PI_DLL_CODEPAGE), bufsize + 2)
         funcname = self._prefix + 'GetAvailableControllerConfigurationsFromDatabase'
         if not getattr(self._handle, funcname)(self._id, configs, bufsize + 1):
             raise GCSError(self._error)
-        configs = configs.value.decode(encoding='cp1252', errors='ignore')
-        debug('GCSDll.getconfigs(id%d): %r', self._id, configs)
+        configs = configs.value.decode(encoding=PI_DLL_CODEPAGE, errors='ignore')
+        PIDebug('GCSDll.getconfigs(id%d): %r', self._id, configs)
         return configs
 
     def GetDllVersionInformation(self):
@@ -694,15 +707,15 @@ class GCSDll(PIGateway):
         :rtype: string
 
         """
-        debug('GCSDll.GetDllVersionInformation()')
+        PIDebug('GCSDll.GetDllVersionInformation()')
 
         bufsize = 100000
-        bufstr = ctypes.create_string_buffer('\000'.encode(), bufsize + 2)
+        bufstr = ctypes.create_string_buffer('\000'.encode(PI_DLL_CODEPAGE), bufsize + 2)
         if getattr(self._handle, self._prefix + 'GetDllVersionInformation')(self._id, bufstr, bufsize) < 0:
             raise GCSError(self._error)
 
-        answer = bufstr.value.decode(encoding='cp1252', errors='ignore')
-        debug('GCSDll.GetDllVersionInformation = %r', answer)
+        answer = bufstr.value.decode(encoding=PI_DLL_CODEPAGE, errors='ignore')
+        PIDebug('GCSDll.GetDllVersionInformation = %r', answer)
         return answer
 
     def GetPIStages3VersionInformation(self):
@@ -711,13 +724,13 @@ class GCSDll(PIGateway):
         :rtype: string
 
         """
-        debug('GCSDll.GetPIStages3VersionInformation()')
+        PIDebug('GCSDll.GetPIStages3VersionInformation()')
 
         bufsize = 100000
-        bufstr = ctypes.create_string_buffer('\000'.encode(), bufsize + 2)
+        bufstr = ctypes.create_string_buffer('\000'.encode(PI_DLL_CODEPAGE), bufsize + 2)
         if getattr(self._handle, self._prefix + 'GetPIStages3VersionInformation')(self._id, bufstr, bufsize) < 0:
             raise GCSError(self._error)
 
-        answer = bufstr.value.decode(encoding='cp1252', errors='ignore')
-        debug('GCSDll.GetPIStages3VersionInformation = %r', answer)
+        answer = bufstr.value.decode(encoding=PI_DLL_CODEPAGE, errors='ignore')
+        PIDebug('GCSDll.GetPIStages3VersionInformation = %r', answer)
         return answer
