@@ -2,13 +2,13 @@
 # -*- coding: utf-8 -*-
 """Provide a socket."""
 
-from logging import debug
 import socket
 
+from ...PILogger import PIDebug
 from .. import GCSError, gcserror
-from ..interfaces.pigateway import PIGateway
+from ..interfaces.pigateway import PIGateway, PI_CONTROLLER_CODEPAGE
 
-__signature__ = 0x7c9504f69d2ce4f136c6f626cfc54ba0
+__signature__ = 0x59c603b46cab28bc52a1b9e4d21ed900
 
 
 class PISocket(PIGateway):
@@ -20,7 +20,7 @@ class PISocket(PIGateway):
         @param port : IP port to use as integer, defaults to 50000.
         @param autoconnect : automaticly connect to controller if True (default)
         """
-        debug('create an instance of PISocket(host=%s, port=%s)', host, port)
+        PIDebug('create an instance of PISocket(host=%s, port=%s)', host, port)
         self._timeout = 7000  # milliseconds
         self._host = host
         self._port = port
@@ -61,8 +61,8 @@ class PISocket(PIGateway):
         """Send 'msg' to the socket.
         @param msg : String to send.
         """
-        debug('PISocket.send: %r', msg)
-        if self._socket.send(msg.encode('cp1252')) != len(msg):
+        PIDebug('PISocket.send: %r', msg)
+        if self._socket.send(msg.encode(PI_CONTROLLER_CODEPAGE)) != len(msg):
             raise GCSError(gcserror.E_2_SEND_ERROR)
 
     def read(self):
@@ -71,14 +71,14 @@ class PISocket(PIGateway):
         """
         try:
             received = self._socket.recv(2048)
-            debug('PISocket.read: %r', received)
+            PIDebug('PISocket.read: %r', received)
         except IOError:
             return u''
-        return received
+        return received.decode(encoding=PI_CONTROLLER_CODEPAGE, errors='ignore')
 
     def flush(self):
         """Flush input buffer."""
-        debug('PISocket.flush()')
+        PIDebug('PISocket.flush()')
         while True:
             try:
                 self._socket.recv(2048)
@@ -90,10 +90,11 @@ class PISocket(PIGateway):
 
     def close(self):
         """Close socket."""
-        debug('PISocket.close: close connection to %s:%s', self._host, self._port)
+        PIDebug('PISocket.close: close connection to %s:%s', self._host, self._port)
         self._connected = False
         self._socket.shutdown(socket.SHUT_RDWR)
         self._socket.close()
+        self.call_connection_status_changed_callback(self)
 
     # Method name "ConnectRS232" doesn't conform to snake_case naming style pylint: disable=C0103
     def ConnectTCPIP(self, ipaddress, ipport=50000):
@@ -103,10 +104,11 @@ class PISocket(PIGateway):
        """
         self._host = ipaddress
         self._port = ipport
-        debug('PISocket.connect: open connection to %s:%s', self._host, self._port)
+        PIDebug('PISocket.connect: open connection to %s:%s', self._host, self._port)
         self._socket = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
         self._socket.connect((self._host, self._port))
         self._socket.setblocking(0)
         self._socket.setsockopt(socket.SOL_TCP, socket.TCP_NODELAY, 1)  # disable Nagle algorithm
         self._connected = True
         self.flush()
+        self.call_connection_status_changed_callback(self)
